Usage — autosubmit 3.9.1 documentation

# Usage

## Command list

`-expid` | Create a new experiment
`-create` | Create specified experiment workflow
`-check` | Check configuration for specified experiment
`-describe` | Show details for specified experiment
`-run` | Run specified experiment
`-inspect` | Generate cmd files
`-test` | Test experiment
`-testcase` | Test case experiment
`-monitor` | Plot specified experiment
`-stats` | Plot statistics for specified experiment
`-setstatus` | Sets job status for an experiment
`-recovery` | Recover specified experiment
`-clean` | Clean specified experiment
`-refresh` | Refresh project directory for an experiment
`-delete` | Delete specified experiment
`-configure` | Configure database and path for autosubmit
`-install` | Install database for Autosubmit on the configured folder
`-archive` | Clean, compress and remove from the experiments’ folder a finalized experiment
`-unarchive` | Restores an archived experiment
`-migrate_exp` | Migrates an experiment from one user to another

-remote_dependencies Submit multiple jobs at same time in order to gain priority.

- How to create an experiment
- How to create a copy of an experiment
- How to create a dummy experiment
- How to configure the experiment
- How to check the experiment configuration
- How to use check in running time:
- How to get details about the experiment
- How to run the experiment
- How to run an experiment that was created with another version
- How to generate cmd files
  - Usage
  - Example
- How to test the experiment
- How to create a test case experiment
- How to monitor the experiment
- Grouping jobs
- How to monitor job statistics
- How to add your particular statistics
- How to change the job status stopping autosubmit
- How to change the job status without stopping autosubmit
- How to stop the experiment
- How to restart the experiment
- How to rerun a part of the experiment
- How to clean the experiment
- How to refresh the experiment project
- How to delete the experiment
- How to add a new job
- How to add a new platform
- How to change the communications library
- How to archive an experiment
- How to unarchive an experiment
- How to migrate an experiment
- How to configure email notifications
- How to request exclusivity or reservation
- Wrappers
  - How to configure
    - Number of jobs in a package
    - Wrapper check time
  - Vertical wrapper
  - Vertical-mixed wrapper
  - Horizontal wrapper
    - Shared-memory Experiments
  - Hybrid wrapper
  - Horizontal-vertical
  - Vertical-horizontal
  - Summary
  - Visualization examples
    - Vertical-mixed wrapper
    - Horizontal wrapper with remote dependencies
- Remote Dependencies
  - How to configure